# install the TDD package (requires internet access):
install.packages('TDD')

# load TDD package
library(TDD)

# load supplement data
load('supplement.RData')
# RETU is trace from station RETU (Tungurahua) recorded with an L-4C 
# CMG40T1 is data from a CMG-40T-1s
# Both are sampled at 100 Hz

##### Deconvolve CMG-40T-1s data

# retrieve discrete response for CMG-40T-1s sampled at 100 Hz
DPZ = GetDPZ(14, 0.01)[[1]]

# deconvolve the response with a low corner at 10 s
X = DeconTrace(CMG40T1, DPZ, fl = 0.1, bitweight = 1.58997e-6) # bitweight is for RT-130

# plot results
plot(1:length(X) * 0.01, X, type = 'l')



##### Deconvolve L-4C response from RETU data

# Calculate poles/zeros of L-4C analog response using sensor parameters.  
# The response of the L-4C is customizable, so it is not precalculated.

# Define sensor response parameters
h = sqrt(0.5) # damping coefficient--depends on shunt used
omega0 = 2*pi # natural frequency (rad/s)
Sense = 0.1016 # high-frequency sensitivity (Vs/m)

# Use damping coefficient, natural frequency, and sensitivity
# to calculate analog poles and zeros
L4C = MakeRespSP(h, omega0, Sense)

# Calculate discrete response of sensor at 100 Hz sampling
DPZ = MakeDPZ(L4C, 0.01, fmin = 0.05, niter = 25000)

# Deconvolve discrete response from data with low corner of 5 s
Y = DeconTrace(RETU, DPZ, fl = 0.2)

# plot results
plot(1:length(Y) * 0.01, Y, type = 'l')
